@@ -22,17 +22,19 @@
 
 #include <gst/gst.h>
 
-void cheese_pipeline_finalize(void);
-void cheese_pipeline_init(void);
-void cheese_pipeline_set_play(void);
-void cheese_pipeline_set_stop(void);
-void cheese_pipeline_button_clicked(GtkWidget *widget);
-void cheese_pipeline_change_effect(void);
-void cheese_pipeline_change_pipeline_type();
-void cheese_pipeline_create(void);
-GstElement *cheese_pipeline_get_ximagesink(void);
-GstElement *cheese_pipeline_get_fakesink(void);
-GstElement *cheese_pipeline_get_pipeline(void);
-gboolean cheese_pipeline_pipeline_is_photo(void);
+void cheese_pipeline_init (void);
+void cheese_pipeline_finalize (void);
+GstElement *cheese_pipeline_get_fakesink (void);
+GstElement *cheese_pipeline_get_pipeline (void);
+GstElement *cheese_pipeline_get_ximagesink (void);
+gboolean    cheese_pipeline_countdown_is_active (void);
+gboolean    cheese_pipeline_pipeline_is_photo (void);
+void        cheese_pipeline_button_clicked (GtkWidget *);
+void        cheese_pipeline_change_effect (void);
+void        cheese_pipeline_change_pipeline_type (void);
+void        cheese_pipeline_create (void);
+void        cheese_pipeline_set_countdown (gboolean);
+void        cheese_pipeline_set_play (void);
+void        cheese_pipeline_set_stop (void);
 
 #endif /* __CHEESE_PIPELINE_H__ */
